==> twinkle_0.4.2.orig.tar.gz: twinkle-0.4.2/src/parser/hdr_referred_by.cpp <==
/*
    Copyright (C) 2005  Michel de Boer <michelboer@xs4all.nl>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "hdr_referred_by.h"
#include "definitions.h"
#include "parse_ctrl.h"

t_hdr_referred_by::t_hdr_referred_by() : t_header() {}

void t_hdr_referred_by::set_display(const string &d) {
	populated = true;
	display = d;
}

void t_hdr_referred_by::set_uri(const string &u) {
	populated = true;
	uri.set_url(u);
}

void t_hdr_referred_by::set_uri(const t_url &u) {
	populated = true;
	uri = u;
}

void t_hdr_referred_by::set_cid(const string &c) {
	populated = true;
	cid = c;
}

void t_hdr_referred_by::set_params(const list<t_parameter> &l) {
	populated = true;
	params = l;
}

void t_hdr_referred_by::add_param(const t_parameter &p) {
	populated = true;
	params.push_back(p);
}

string t_hdr_referred_by::encode(void) const {
	string s;

	if (!populated) return s;

	if (t_parser::compact_headers) {
		s = "b: ";
	} else {
		s = "Referred-By: ";
	}

	if (display.size() > 0) {
		s += '"';
		s += display;
		s += '"';
		s += ' ';
	}

	s += '<';
	s += uri.encode();
	s += '>';

	if (cid.size() > 0) {
		s += ";cid=";
		s += cid;
	}

	s += param_list2str(params);
	s += CRLF;

	return s;
}

==> twinkle_0.9.orig.tar.gz: twinkle-0.9/src/parser/hdr_referred_by.cpp <==
/*
    Copyright (C) 2005-2006  Michel de Boer <michelboer@xs4all.nl>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "hdr_referred_by.h"
#include "definitions.h"
#include "parse_ctrl.h"

t_hdr_referred_by::t_hdr_referred_by() : t_header() {}

void t_hdr_referred_by::set_display(const string &d) {
	populated = true;
	display = d;
}

void t_hdr_referred_by::set_uri(const string &u) {
	populated = true;
	uri.set_url(u);
}

void t_hdr_referred_by::set_uri(const t_url &u) {
	populated = true;
	uri = u;
}

void t_hdr_referred_by::set_cid(const string &c) {
	populated = true;
	cid = c;
}

void t_hdr_referred_by::set_params(const list<t_parameter> &l) {
	populated = true;
	params = l;
}

void t_hdr_referred_by::add_param(const t_parameter &p) {
	populated = true;
	params.push_back(p);
}

string t_hdr_referred_by::encode(void) const {
	string s;

	if (!populated) return s;

	if (t_parser::compact_headers) {
		s = "b: ";
	} else {
		s = "Referred-By: ";
	}

	s += encode_value();
	s += CRLF;

	return s;
}

string t_hdr_referred_by::encode_value(void) const {
	string s;

	if (!populated) return s;

	if (display.size() > 0) {
		s += '"';
		s += display;
		s += '"';
		s += ' ';
	}

	s += '<';
	s += uri.encode();
	s += '>';

	if (cid.size() > 0) {
		s += ";cid=";
		s += cid;
	}

	s += param_list2str(params);

	return s;
}

string t_hdr_referred_by::encode_env(void) const {
	string s;
	
	s = "SIP_REFERRED_BY=";
	s += encode_value();
	
	return s;
}
